Module title

Module title 

A side effect that controls document.title.

To use this side effect, you need to register TitleProvider like a React Context Provider in your Application.

Title can be set with Title Component.

Only value provided to the last created Title will be set.

Structs

TitleProviderProps
The Properties for Title Provider

Type Aliases

Title
Set a title
TitleProvider
The Title Provider